precision highp float;
varying vec2 textureCoordinate;
uniform sampler2D inputImageTexture;
uniform vec2 inputSize;
uniform vec2 direction;
uniform float effectValue;

#define BMIX 0.4
#define OMIX 0.1
#define MAX_BLUR 20.0

const float PI = 3.141592653589793238462;
const float inv_sqrt_2pi = 0.3989422804014327;
float soft_light(float base, float blend)
{
    return (blend < 0.5) ? (2.0 * base * blend + base * base * (1.0 - 2.0 * blend)) : (sqrt(base) * (2.0 * blend - 1.0) + 2.0 * base * (1.0 - blend));
}
vec3 soft_light(vec3 base, vec3 blend)
{
    return vec3(soft_light(base.x,blend.x),soft_light(base.y,blend.y),soft_light(base.z,blend.z));
}
vec3 screen( vec3 s, vec3 d )
{
    return s + d - s * d;
}
float luma(vec4 color) {
    return clamp(dot(color.rgb, vec3(0.299, 0.587, 0.114)),0.0,1.0);
}
float gaussianf(float sigma, float dist)
{
    float a = dist / sigma;
    return (inv_sqrt_2pi / sigma ) * exp( -0.5 * a * a );
}

vec4 fast_gaussian_blur(sampler2D image, vec2 uv,vec2 resolution, vec2 direction, float blur)
{
    vec4 color = vec4(0.0);
    float coef = gaussianf(blur,0.0);
    color += texture2D(image, uv) * coef;
    float kernel_s = blur * 4.0;
    //removed precomputing weights by onehade
    float prev = gaussianf(blur, 0.0);
    for (float i = 0.0; i < kernel_s; i++) {
        float w1 = prev;
        float w2 = gaussianf(blur, i + 1.0);
        prev = w2; //storing redudant weight for next loop
        float c = w1 + w2;
        vec2 off1 = vec2((i * w1 + (i + 1.0) * w2) / c) * direction / resolution;
        color += texture2D(image, uv - off1 ) * c;
        color += texture2D(image, uv + off1 ) * c;
        coef += c + c;
    }

    return color/coef;
}

void main()
{
    vec2 uv = textureCoordinate;
    if(effectValue > 0.0) {
        gl_FragColor = fast_gaussian_blur(inputImageTexture, uv, inputSize, direction, effectValue * MAX_BLUR);
    } else {
        gl_FragColor = texture2D(inputImageTexture, uv);
    }
}