precision highp float;
varying vec2 textureCoordinate;
uniform sampler2D inputImageTexture;
uniform int splicingMode;//0:none;1:左背景 右前景;2:左背景 右 alpha;3:左上背景 左下背景alpha，右上前景 右下前景 alpha;4:左上背景 右上前景 左下人物区域叠加层 右下前后景alpha
uniform int outputIdx;
uniform vec3 color;
uniform int isReplaceColor;
uniform int isPremultiplied;


vec3 rgb2hsv(vec3 color) {
    vec4 K = vec4(0.0, -1.0 / 3.0, 2.0 / 3.0, -1.0);
    vec4 p = mix(vec4(color.bg, K.wz), vec4(color.gb, K.xy), step(color.b, color.g));
    vec4 q = mix(vec4(p.xyw, color.r), vec4(color.r, p.yzx), step(p.x, color.r));

    float d = q.x - min(q.w, q.y);
    float e = 1.0e-10;
    return vec3(abs(q.z + (q.w - q.y) / (6.0 * d + e)), d / (q.x + e), q.x);
}

vec3 hsv2rgb(vec3 color) {
    vec4 K = vec4(1.0, 2.0 / 3.0, 1.0 / 3.0, 3.0);
    vec3 p = abs(fract(color.xxx + K.xyz) * 6.0 - K.www);
    return color.z * mix(K.xxx, clamp(p - K.xxx, 0.0, 1.0), color.y);
}

float lum(vec4 color) {
    return dot(color.rgb, vec3(0.2126, 0.7152, 0.0722));
}

void main()
{
    vec2 uv = textureCoordinate;
    uv.y = 1.0 - uv.y;
    vec4 col = vec4(0.0);
    if(splicingMode == 1) {
        uv.x /= 2.0;
        if(outputIdx == 0) {
            col = texture2D(inputImageTexture, uv);
        } else if(outputIdx == 1) {
            col = texture2D(inputImageTexture, vec2(uv.x + 0.5, uv.y));
        }
    } else if(splicingMode == 2) {
        uv.x /= 2.0;
        col = texture2D(inputImageTexture, uv);
        col.a = texture2D(inputImageTexture, vec2(uv.x + 0.5, uv.y)).r;
    } else if(splicingMode == 3) {
        //uv.x /= 3.0;
//        if(outputIdx == 0) {
//            col = texture2D(inputImageTexture, vec2(uv.x*0.4, uv.y));
//            col.a = texture2D(inputImageTexture, vec2(0.8 + uv.x*0.2, uv.y/2.0)).r;
//        } else if(outputIdx == 1) {
//            col = texture2D(inputImageTexture, vec2(0.4 + uv.x*0.4, uv.y));
//            col.a = texture2D(inputImageTexture, vec2(0.8 + uv.x*0.2, 0.5 + uv.y/2.0)).r;
//        }

        uv = uv / 2.0;
        if(outputIdx == 0) {
            col = texture2D(inputImageTexture, vec2(uv.x, uv.y + 0.5));
            if(isPremultiplied > 0) {
                col.a = lum(texture2D(inputImageTexture, uv));
            } else {
                col.a = texture2D(inputImageTexture, uv).r;
            }
        } else if(outputIdx == 1) {
            col = texture2D(inputImageTexture, vec2(uv.x + 0.5, uv.y + 0.5));
            if(isPremultiplied > 0) {
                col.a = lum(texture2D(inputImageTexture, vec2(uv.x + 0.5, uv.y)));
            } else {
                col.a = texture2D(inputImageTexture, vec2(uv.x + 0.5, uv.y)).r;
            }
        }
        //col.a *= smoothstep(0.0, 0.8, col.a + 0.2);
    } else if(splicingMode == 4) {
        if(outputIdx == 0) {
            uv = uv / 2.0;
            col = texture2D(inputImageTexture, vec2(uv.x, uv.y + 0.5));
            uv.x += 0.5;
            uv.y /= 2.0;
            uv.y += 0.25;
            col.a = texture2D(inputImageTexture, uv).r;
            //col = vec4(vec3(1.0),texture2D(inputImageTexture, uv).r);
        } else if(outputIdx == 1) {
            uv = uv / 2.0;
            col = texture2D(inputImageTexture, vec2(uv.x + 0.5, uv.y + 0.5));
            uv.x += 0.5;
            uv.y /= 2.0;
            //uv.y += 0.75;
            col.a = texture2D(inputImageTexture, uv).g;
        } else if(outputIdx == 2) {
            uv = uv / 2.0;
            col = texture2D(inputImageTexture, vec2(uv.x, uv.y));
        }
    } else {
        col = texture2D(inputImageTexture, uv);
    }

    if(isReplaceColor > 0) {
        col.rgb = color;
    }

    vec3 hsvColor = rgb2hsv(col.rgb);
    col.rgb = hsv2rgb(vec3(hsvColor.r,hsvColor.g*1.1,hsvColor.b));

    if(isPremultiplied > 0) {
        col.rgb /= col.a;
    }

    gl_FragColor = col;
}