precision highp float;
varying highp vec2 textureCoordinate;
uniform sampler2D inputImageTexture;
uniform int zoomIndex;

vec3 rgb2hsv(vec3 color) {
    vec4 K = vec4(0.0, -1.0 / 3.0, 2.0 / 3.0, -1.0);
    vec4 p = mix(vec4(color.bg, K.wz), vec4(color.gb, K.xy), step(color.b, color.g));
    vec4 q = mix(vec4(p.xyw, color.r), vec4(color.r, p.yzx), step(p.x, color.r));

    float d = q.x - min(q.w, q.y);
    float e = 1.0e-10;
    return vec3(abs(q.z + (q.w - q.y) / (6.0 * d + e)), d / (q.x + e), q.x);
}

vec3 hsv2rgb(vec3 color) {
    vec4 K = vec4(1.0, 2.0 / 3.0, 1.0 / 3.0, 3.0);
    vec3 p = abs(fract(color.xxx + K.xyz) * 6.0 - K.www);
    return color.z * mix(K.xxx, clamp(p - K.xxx, 0.0, 1.0), color.y);
}

vec2 zoom(vec2 uv,  vec2 zoom) {
    uv -= 0.5;
    mat2 m = mat2(vec2(zoom.x , 0.0),vec2(0.0, zoom.y));
    uv = m*uv;
    uv += 0.5;
    return uv;
}

vec4 unpremultiply(vec4 s) {
    return vec4(s.rgb/max(s.a, 0.00001), s.a);
}

vec4 premultiply(vec4 s) {
    return vec4(s.rgb * s.a, s.a);
}

vec4 normalBlend(vec4 Cb, vec4 Cs) {
    vec4 dst = premultiply(Cb);
    vec4 src = premultiply(Cs);
    return unpremultiply(src + dst * (1.0 - src.a));
}

void main() {
    vec2 uv = textureCoordinate;

    vec4 resultColor = texture2D(inputImageTexture, uv);
    if(zoomIndex == 0) {
        gl_FragColor = resultColor;
        return;
    }

    for(int i = 0; i <= zoomIndex; ++i){
        float zoomValue = 1.0 + 0.1* float(i);
        if(i == 0){
            uv = zoom(uv,vec2(zoomValue ,zoomValue));
        }else{
            uv = zoom(uv,vec2(zoomValue*-1.0 ,zoomValue));
        }
        vec4 zoomColor = vec4(0.0);
        if(uv.x >= 0.001 && uv.x <= 0.999 && uv.y >= 0.001 && uv.y <= 0.999) {
            zoomColor = texture2D(inputImageTexture, uv);
        }
        resultColor.rgb = vec3((resultColor.x + resultColor.y + resultColor.z) / 3.0);
        resultColor = normalBlend(resultColor, zoomColor);
    }

    gl_FragColor = resultColor;
}